import { Printer } from '../printer/printer.js';
import { AmplifyIoHostEventMessage } from '@aws-amplify/plugin-types';
import { AmplifyIOEventsBridgeSingletonFactory } from './amplify_io_events_bridge_singleton_factory.js';
/**
 * Amplify events logger class. Implements several loggers that connect
 * to the amplify_io_event_bridge for showing relevant information to customers
 */
export declare class AmplifyEventLogger {
    private readonly printer;
    private readonly amplifyIOEventsBridgeSingletonFactory;
    private cfnDeploymentProgressLogger;
    private outputs;
    /**
     * a logger instance to be used for CDK events
     */
    constructor(printer: Printer, amplifyIOEventsBridgeSingletonFactory: AmplifyIOEventsBridgeSingletonFactory);
    getEventLoggers: () => {
        notify: (<T>(msg: AmplifyIoHostEventMessage<T>) => Promise<void>)[];
    };
    /**
     * Log debug messages
     */
    debug: <T>(msg: AmplifyIoHostEventMessage<T>) => Promise<void>;
    amplifyNotifications: <T>(msg: AmplifyIoHostEventMessage<T>) => Promise<void>;
    cdkDeploymentProgress: <T>(msg: AmplifyIoHostEventMessage<T>) => Promise<void>;
    /**
     * Displays pretty print of cfn deployment progress. Disabled if debug logging is turned on
     * @param msg a CDK event
     */
    fancyCfnDeploymentProgress: <T>(msg: AmplifyIoHostEventMessage<T>) => Promise<void>;
    /**
     * Non fancy cfn deployment progress for ci/cd or files
     */
    nonTtyCfnDeploymentProgress: <T>(msg: AmplifyIoHostEventMessage<T>) => Promise<void>;
    private getNewCfnDeploymentProgressLogger;
    private safeJsonStringifyForDebug;
}
//# sourceMappingURL=amplify_event_loggers.d.ts.map