import { AmplifyIOHost, AmplifyIoHostEventMessage, AmplifyIoHostEventRequestMessageIoRequest } from '@aws-amplify/plugin-types';
import { Printer } from '../printer/printer.js';
/**
 * Implements IIoHost interface of AmplifyIOHost
 */
export declare class AmplifyIOEventsBridge implements AmplifyIOHost {
    private readonly eventHandlers;
    private readonly printer;
    /**
     * Constructor for AmplifyIOEventsBridge
     * @param eventHandlers - event handlers to be called when events are received
     * @param eventHandlers.notify - event handler for notify events
     */
    constructor(eventHandlers: {
        notify?: (<T>(msg: AmplifyIoHostEventMessage<T>) => Promise<void>)[];
    }, printer?: Printer);
    /**
     * Receive amplify events and fan out notifying anyone interested.
     */
    notify<T>(msg: AmplifyIoHostEventMessage<T>): Promise<void>;
    /**
     * Receive amplify events and fan out asking everyone if they have a response for this request
     * Custom event handlers are currently not supported for this event type
     */
    requestResponse<T, U>(msg: AmplifyIoHostEventRequestMessageIoRequest<T, U>): Promise<U>;
}
//# sourceMappingURL=amplify_io_events_bridge.d.ts.map