import { AmplifyIOHost } from '@aws-amplify/plugin-types';
/**
 * A class representing re-writable display lines
 */
export declare class RewritableBlock {
    private readonly getBlockWidth;
    private readonly getBlockHeight;
    private readonly ioHost;
    private lastHeight;
    /**
     * Constructor for RewritableBlock
     * @param getBlockWidth A function that returns the width of the block
     * @param getBlockHeight A function that returns the height of the block
     * @param ioHost to send new updates to display
     */
    constructor(getBlockWidth: () => number, getBlockHeight: () => number, ioHost: AmplifyIOHost);
    /**
     * Display the given lines in this rewritable block. It expands to make room for more lines
     * and compress when not needed. It also takes care of not overflowing the block.
     */
    displayLines(lines: string[]): Promise<void>;
    /**
     * Clear to the end of line
     */
    cll: () => string;
    /**
     * Wrap extra long lines while still being in the rewritable block
     */
    terminalWrap: (width: number | undefined, lines: string[]) => string[];
    /**
     * Make sure there are no hidden newlines in the input strings
     */
    expandNewlines: (lines: string[]) => string[];
    getMaxBlockHeight: (windowHeight: number | undefined, lastHeight: number, lines: string[]) => number;
}
//# sourceMappingURL=rewritable_block.d.ts.map