/// <reference types="node" resolution-mode="require"/>
/// <reference types="node" resolution-mode="require"/>
import { WriteStream } from 'node:tty';
export type RecordValue = string | number | string[] | Date;
/**
 * The class that pretty prints to the output stream.
 */
export declare class Printer {
    private readonly minimumLogLevel;
    readonly stdout: WriteStream | NodeJS.WritableStream;
    readonly stderr: WriteStream | NodeJS.WritableStream;
    private readonly refreshRate;
    readonly ttyEnabled: boolean;
    private currentSpinner;
    /**
     * Sets default configs
     */
    constructor(minimumLogLevel: LogLevel, stdout?: WriteStream | NodeJS.WritableStream, stderr?: WriteStream | NodeJS.WritableStream, refreshRate?: number, ttyEnabled?: boolean);
    /**
     * Prints a given message to output stream followed by a newline.
     * If a spinner is running, honor it and keep the spinner at the cursor running
     */
    print: (message: string) => void;
    /**
     * Prints a new line to output stream
     */
    printNewLine: () => void;
    /**
     * Logs a message to the output stream at the given log level followed by a newline
     */
    log: (message: string, level?: LogLevel) => void;
    /**
     * Logs a message with animated spinner
     * If stdout is not a TTY, the message is logged at the info level without a spinner
     */
    indicateProgress: (message: string, callback: () => Promise<void>, successMessage?: string) => Promise<void>;
    /**
     * Start a spinner for the given message.
     * If stdout is not a TTY, the message is logged at the info level without a spinner
     */
    startSpinner: (message: string, options?: {
        timeoutSeconds: number;
    }) => void;
    isSpinnerRunning: () => boolean;
    /**
     * Stop the current running spinner
     */
    stopSpinner: (successMessage?: string) => void;
    /**
     * Update the current running spinner options, e.g. message or prefixText
     */
    updateSpinner: (options: {
        message?: string;
        prefixText?: string;
    }) => void;
    /**
     * Clears the console
     */
    clearConsole: () => void;
    private printWhileSpinnerRunning;
    private stringify;
    private getLogPrefix;
    private prefixedMessage;
}
export declare enum LogLevel {
    ERROR = 0,
    WARN = 1,
    INFO = 2,
    DEBUG = 3
}
//# sourceMappingURL=printer.d.ts.map